@@ -12,6 +12,8 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with this program; if not, write to the Free Software Foundation,
 # Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+from __future__ import annotations
+
 from gemseo_templator.blocks.template import Block
 from gemseo_templator.blocks.template import WebLink
 
@@ -28,6 +30,6 @@ block = Block(
             url="_modules/gemseo.algos.parameter_space.html",
         ),
     ],
-    examples="examples/cache/index.html",
+    examples="examples/design_space/index.html",
     info="design_space/design_space.html",
 )
