@@ -28,6 +28,9 @@ from numpy import ndarray
 
 from gemseo.algos.driver_lib import DriverDescription
 from gemseo.algos.driver_lib import DriverLib
+from gemseo.algos.first_order_stop_criteria import is_kkt_residual_norm_reached
+from gemseo.algos.first_order_stop_criteria import kkt_residual_computation
+from gemseo.algos.first_order_stop_criteria import KKTReached
 from gemseo.algos.opt_problem import OptimizationProblem
 from gemseo.algos.stop_criteria import FtolReached
 from gemseo.algos.stop_criteria import is_f_tol_reached
@@ -58,13 +61,28 @@ class OptimizationAlgorithmDescription(DriverDescription):
 
 
 class OptimizationLibrary(DriverLib):
-    """Optimization library base class See DriverLib."""
+    """Base optimization library defining a collection of optimization algorithms.
+
+    Typically used as:
+
+    #. Instantiate an :class:`.OptimizationLibrary`.
+    #. Select the algorithm with :attr:`.algo_name`.
+    #. Solve an :class:`.OptimizationProblem` with :meth:`.execute`.
+
+    Note:
+        The missing current values
+        of the :class:`.DesignSpace` attached to the :class:`.OptimizationProblem`
+        are automatically initialized
+        with the method :meth:`.DesignSpace.initialize_missing_current_values`.
+    """
 
     MAX_ITER = "max_iter"
     F_TOL_REL = "ftol_rel"
     F_TOL_ABS = "ftol_abs"
     X_TOL_REL = "xtol_rel"
     X_TOL_ABS = "xtol_abs"
+    _KKT_TOL_ABS = "kkt_tol_abs"
+    _KKT_TOL_REL = "kkt_tol_rel"
     STOP_CRIT_NX = "stop_crit_n_x"
     # Maximum step for the line search
     LS_STEP_SIZE_MAX = "max_ls_step_size"
@@ -81,6 +99,9 @@ class OptimizationLibrary(DriverLib):
         self._ftol_abs = 0.0
         self._xtol_rel = 0.0
         self._xtol_abs = 0.0
+        self.__kkt_abs_tol = 0.0
+        self.__kkt_rel_tol = 0.0
+        self.__ref_kkt_norm = None
         self._stop_crit_n_x = 3
 
     def __algorithm_handles(self, algo_name: str, eq_constraint: bool):
@@ -174,6 +195,9 @@ class OptimizationLibrary(DriverLib):
 
         Specific method to be executed just before _run method call.
 
+        The missing current values of the :class:`.DesignSpace` are initialized
+        with the method :meth:`.DesignSpace.initialize_missing_current_values`.
+
         Args:
             problem: The optimization problem.
             algo_name: The name of the algorithm.
@@ -197,14 +221,26 @@ class OptimizationLibrary(DriverLib):
         self._ftol_abs = options.get(self.F_TOL_ABS, 0.0)
         self._xtol_rel = options.get(self.X_TOL_REL, 0.0)
         self._xtol_abs = options.get(self.X_TOL_ABS, 0.0)
+        self.__ineq_tolerance = options.get(self.INEQ_TOLERANCE, problem.ineq_tolerance)
         self._stop_crit_n_x = options.get(self.STOP_CRIT_NX, 3)
-        self.init_iter_observer(max_iter, " ")
+        self.__kkt_abs_tol = options.get(self._KKT_TOL_ABS, None)
+        self.__kkt_rel_tol = options.get(self._KKT_TOL_REL, None)
+        self.init_iter_observer(max_iter)
         problem.add_callback(self.new_iteration_callback)
-        eval_jac = self.is_algo_requires_grad(algo_name)
-        normalize = options.get(self.NORMALIZE_DESIGN_SPACE_OPTION, self._NORMALIZE_DS)
+        if (
+            self.__kkt_abs_tol is not None or self.__kkt_rel_tol is not None
+        ) and self.descriptions[self.algo_name].require_gradient:
+            problem.add_callback(
+                self._check_kkt_from_database, each_new_iter=False, each_store=True
+            )
         # First, evaluate all functions at x_0. Some algorithms don't do this
+        self.problem.design_space.initialize_missing_current_values()
         self.problem.evaluate_functions(
-            eval_jac=eval_jac, eval_obj=True, normalize=normalize
+            eval_jac=self.is_algo_requires_grad(algo_name),
+            eval_obj=True,
+            normalize=options.get(
+                self.NORMALIZE_DESIGN_SPACE_OPTION, self._NORMALIZE_DS
+            ),
         )
 
     @staticmethod
@@ -242,7 +278,8 @@ class OptimizationLibrary(DriverLib):
         return True
 
     def new_iteration_callback(self, x_vect: ndarray | None = None) -> None:
-        """
+        """Verify the design variable and objective value stopping criteria.
+
         Raises:
             FtolReached: If the defined relative or absolute function
                 tolerance is reached.
@@ -255,7 +292,41 @@ class OptimizationLibrary(DriverLib):
             self.problem, self._ftol_rel, self._ftol_abs, self._stop_crit_n_x
         ):
             raise FtolReached()
+
         if is_x_tol_reached(
             self.problem, self._xtol_rel, self._xtol_abs, self._stop_crit_n_x
         ):
             raise XtolReached()
+
+    def _check_kkt_from_database(self, x_vect: ndarray | None = None) -> None:
+        """Verify, if required, KKT norm stopping criterion at each database storage.
+
+        Raises:
+            KKTReached: If the absolute tolerance on the KKT residual is reached.
+        """
+        check_kkt = True
+        function_names = [
+            self.problem.get_objective_name()
+        ] + self.problem.get_constraints_names()
+        database = self.problem.database
+        for function_name in function_names:
+            if (
+                database.get_f_of_x(database.get_gradient_name(function_name), x_vect)
+                is None
+            ) or (database.get_f_of_x(function_name, x_vect) is None):
+                check_kkt = False
+                break
+        if check_kkt and (self.__ref_kkt_norm is None):
+            self.__ref_kkt_norm = kkt_residual_computation(
+                self.problem, x_vect, self.__ineq_tolerance
+            )
+
+        if check_kkt and is_kkt_residual_norm_reached(
+            self.problem,
+            x_vect,
+            kkt_abs_tol=self.__kkt_abs_tol,
+            kkt_rel_tol=self.__kkt_rel_tol,
+            ineq_tolerance=self.__ineq_tolerance,
+            reference_residual=self.__ref_kkt_norm,
+        ):
+            raise KKTReached()
