@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 # Copyright 2021 IRT Saint Exupéry, https://www.irt-saintexupery.com
 #
 # This program is free software; you can redistribute it and/or
@@ -13,22 +12,23 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with this program; if not, write to the Free Software Foundation,
 # Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
-
 # Contributors:
 #    INITIAL AUTHORS - initial API and implementation and/or initial
 #                           documentation
 #        :author: Matthias De Lozzo
 #    OTHER AUTHORS   - MACROSCOPIC CHANGES
 """Computation of tolerance intervals from a data-fitted normal distribution."""
-
-from typing import Tuple
+from __future__ import annotations
 
 import openturns as ot
-from numpy import array, inf, ndarray
-from past.utils import old_div
+from numpy import array
+from numpy import inf
+from numpy import ndarray
 
 from gemseo.uncertainty.statistics.tolerance_interval.distribution import (
     ToleranceInterval,
+)
+from gemseo.uncertainty.statistics.tolerance_interval.distribution import (
     ToleranceIntervalSide,
 )
 
@@ -45,35 +45,34 @@ class NormalToleranceInterval(ToleranceInterval):
 
     def __init__(
         self,
-        size,  # type: int
-        mean,  # type: float
-        std,  # type: float
-    ):  # type:(...) -> None
-        # noqa: D205 D212 D415
-        """
+        size: int,
+        mean: float,
+        std: float,
+    ) -> None:
+        """.. # noqa: D205 D212 D415
         Args:
             mean: The estimation of the mean of the normal distribution.
             std: The estimation of the standard deviation of the normal distribution.
         """
-        super(NormalToleranceInterval, self).__init__(size)
+        super().__init__(size)
         self.__mean = mean
         self.__std = std
 
     def _compute(
         self,
-        coverage,  # type: float
-        alpha,  # type: float
-        size,  # type: int
-        side,  # type: ToleranceIntervalSide
-    ):  # type: (...) -> Tuple[ndarray,ndarray]
+        coverage: float,
+        alpha: float,
+        size: int,
+        side: ToleranceIntervalSide,
+    ) -> tuple[ndarray, ndarray]:
         if side in [
             ToleranceIntervalSide.UPPER,
             ToleranceIntervalSide.LOWER,
         ]:
-            offset = ot.Normal().computeQuantile(coverage)[0] * size ** 0.5
+            offset = ot.Normal().computeQuantile(coverage)[0] * size**0.5
             student = ot.Student(size - 1, offset, 1.0)
             student_quantile = student.computeQuantile(1 - alpha)[0]
-            tolerance_factor = old_div(student_quantile, size ** 0.5)
+            tolerance_factor = student_quantile / size**0.5
 
             if side == ToleranceIntervalSide.UPPER:
                 upper = self.__mean + tolerance_factor * self.__std
@@ -86,7 +85,7 @@ class NormalToleranceInterval(ToleranceInterval):
             z_p = ot.Normal().computeQuantile((1 + coverage) / 2.0)[0]
             u_term = (1 + 1.0 / size) ** 0.5 * z_p
             chi_square = ot.ChiSquare(size - 1)
-            v_term = (old_div((size - 1), chi_square.computeQuantile(alpha)[0])) ** 0.5
+            v_term = ((size - 1) / chi_square.computeQuantile(alpha)[0]) ** 0.5
             w_term = (
                 1
                 + (size - 3 - chi_square.computeQuantile(alpha)[0])
