@@ -66,20 +66,27 @@ class LoggingContext:
     Change the level of the logger in a ``with`` block.
 
     Examples:
-        logger.setLevel(logging.INFO)
-        logger.info("This should appear.")
-        with LoggingContext(logger, logging.WARNING):
-            logger.warning("This should appear.")
-            logger.info("This should not appear.")
-
-        logger.info("This should appear.")
+        >>> logger = logger.getLogger()
+        >>> logger.setLevel(logging.INFO)
+        >>> logger.info("This should appear.")
+        >>> with LoggingContext():
+        >>>    logger.warning("This should appear.")
+        >>>    logger.info("This should not appear.")
+        >>>
+        >>> logger.info("This should appear.")
 
     Source: `Logging Cookbook
     <https://docs.python.org/3/howto/
     logging-cookbook.html#using-a-context-manager-for-selective-logging>`_
     """
 
-    def __init__(self, logger, level, handler=None, close=True):
+    def __init__(
+        self,
+        logger: logging.Logger = logging.root,
+        level: int = logging.WARNING,
+        handler: logging.StreamHandler | None = None,
+        close: bool = True,
+    ) -> None:
         """
         Args:
             logger: The logger.
@@ -92,14 +99,14 @@ class LoggingContext:
         self.handler = handler
         self.close = close
 
-    def __enter__(self):
+    def __enter__(self) -> None:
         if self.level is not None:
             self.old_level = self.logger.level
             self.logger.setLevel(self.level)
         if self.handler:
             self.logger.addHandler(self.handler)
 
-    def __exit__(self, et, ev, tb):
+    def __exit__(self, exc_type, exc_value, traceback) -> None:
         if self.level is not None:
             self.logger.setLevel(self.old_level)
         if self.handler:
