@@ -16,11 +16,11 @@
 #    INITIAL AUTHORS - API and implementation and/or documentation
 #      :author: Damien Guenot - 28 avr. 2016
 #    OTHER AUTHORS   - MACROSCOPIC CHANGES
+from __future__ import annotations
+
 import re
 from pathlib import Path
 from typing import Any
-from typing import Dict
-from typing import Optional
 
 import pytest
 from gemseo.algos.doe.doe_factory import DOEFactory
@@ -112,7 +112,7 @@ def test_wrong_arguments(options):
 def get_expected_nsamples(
     algo: str,
     dim: int,
-    n_samples: Optional[int] = None,
+    n_samples: int | None = None,
 ) -> int:
     """Returns the expected number of samples.
 
@@ -136,7 +136,7 @@ def get_expected_nsamples(
 def get_options(
     algo_name: str,
     dim: int,
-) -> Dict[str, Any]:
+) -> dict[str, Any]:
     """Returns the options of the algorithms.
 
     Args:
