@@ -18,8 +18,9 @@
 #        :author: Benoit Pauwels
 #    OTHER AUTHORS   - MACROSCOPIC CHANGES
 """Tests for the Generic Tool for Optimization (GTOpt) of pSeven Core."""
+from __future__ import annotations
+
 from pathlib import Path
-from typing import Union
 
 import pytest
 from gemseo.algos.database import Database
@@ -33,13 +34,13 @@ from numpy.testing import assert_allclose  # noqa: E402
 from gemseo.algos.design_space import DesignSpace  # noqa: E402
 from gemseo.algos.opt.opt_factory import OptimizersFactory  # noqa: E402
 from gemseo.algos.opt_problem import OptimizationProblem  # noqa: E402
-from gemseo.core.mdofunctions.mdo_function import MDOLinearFunction  # noqa: E402
+from gemseo.core.mdofunctions.mdo_linear_function import MDOLinearFunction  # noqa: E402
 from gemseo.problems.analytical.power_2 import Power2  # noqa: E402
 from gemseo.problems.analytical.rosenbrock import Rosenbrock  # noqa: E402
 
 
 def check_on_problem(
-    problem: Union[Rosenbrock, Power2],
+    problem: Rosenbrock | Power2,
     algo_name: str,
     **options,
 ) -> OptimizationProblem:
