@@ -16,6 +16,8 @@
 #    INITIAL AUTHORS - initial API and implementation and/or initial
 #                           documentation
 #        :author: Benoit Pauwels
+from __future__ import annotations
+
 from unittest.case import TestCase
 
 from gemseo.algos.design_space import DesignSpace
@@ -23,7 +25,7 @@ from gemseo.algos.opt.lib_scipy_linprog import ScipyLinprog
 from gemseo.algos.opt.opt_factory import OptimizersFactory
 from gemseo.algos.opt_problem import OptimizationProblem
 from gemseo.core.mdofunctions.mdo_function import MDOFunction
-from gemseo.core.mdofunctions.mdo_function import MDOLinearFunction
+from gemseo.core.mdofunctions.mdo_linear_function import MDOLinearFunction
 from gemseo.problems.analytical.rosenbrock import Rosenbrock
 from numpy import allclose
 from numpy import array
