@@ -17,6 +17,8 @@
 #                           documentation
 #        :author: Charlie Vanaret
 #    OTHER AUTHORS   - MACROSCOPIC CHANGES
+from __future__ import annotations
+
 import logging
 import re
 from pathlib import Path
@@ -30,7 +32,6 @@ from gemseo.algos.opt_problem import OptimizationProblem
 from gemseo.algos.opt_result import OptimizationResult
 from gemseo.core.mdofunctions.mdo_function import MDOFunction
 from gemseo.problems.sobieski.core.problem import SobieskiProblem
-from gemseo.utils.string_tools import MultiLineString
 from numpy import array
 from numpy import array_equal
 from numpy import float64
@@ -203,7 +204,7 @@ def test_creation_4():
     design_space.add_variable("varname")
     with pytest.raises(
         KeyError,
-        match=re.escape("The design variables ['varname'] have no current value."),
+        match=re.escape("There is no current value for the design variables: varname"),
     ):
         design_space.get_current_value(normalize=True)
 
@@ -381,9 +382,7 @@ def test_active_bounds():
 
     with pytest.raises(
         KeyError,
-        match=re.escape(
-            "The design variables {} have no current value.".format(["x", "y", "z"])
-        ),
+        match=re.escape("There is no current value for the design variables: x, y, z."),
     ):
         design_space.get_active_bounds()
 
@@ -392,7 +391,7 @@ def test_active_bounds():
 def test_get_indexed_variables_names(index, expected):
     """Check the variables names obtained with get_indexed_variables_names()."""
     design_space = DesignSpace()
-    design_space.add_variable("x", size=1)
+    design_space.add_variable("x")
     design_space.add_variable("z", size=2)
     assert design_space.get_indexed_variables_names()[index] == expected
 
@@ -763,17 +762,46 @@ def test_fail_import():
         DesignSpace().import_hdf(FAIL_HDF)
 
 
-def test_get_pretty_table():
-    """Check that a design space is correctly rendered."""
+@pytest.fixture(scope="module")
+def table_template() -> str:
+    return """
++------+-------------+-------+-------------+-------+
+| name | lower_bound | value | upper_bound | type  |
++------+-------------+-------+-------------+-------+
+| x    |     -inf    |  None |     inf     | float |
+| y{index_0} |     -inf    |  None |     inf     | float |
+| y{index_1} |     -inf    |  None |     inf     | float |
++------+-------------+-------+-------------+-------+
+""".strip()
+
+
+@pytest.fixture(scope="module")
+def design_space_2() -> DesignSpace:
+    """Return a design space with scalar and vectorial variables."""
     design_space = DesignSpace()
     design_space.add_variable("x")
-    msg = MultiLineString()
-    msg.add("+------+-------------+-------+-------------+-------+")
-    msg.add("| name | lower_bound | value | upper_bound | type  |")
-    msg.add("+------+-------------+-------+-------------+-------+")
-    msg.add("| x    |     -inf    |  None |     inf     | float |")
-    msg.add("+------+-------------+-------+-------------+-------+")
-    assert str(msg) == design_space.get_pretty_table().get_string()
+    design_space.add_variable("y", size=2)
+    return design_space
+
+
+@pytest.mark.parametrize(
+    "with_index,indexes", ((True, ("[0]", "[1]")), (False, ("   ", "   ")))
+)
+def test_get_pretty_table(table_template, design_space_2, with_index, indexes):
+    """Check that a design space is correctly rendered."""
+    assert (
+        table_template.format(index_0=indexes[0], index_1=indexes[1])
+        == design_space_2.get_pretty_table(with_index=with_index).get_string()
+    )
+
+
+@pytest.mark.parametrize("name", ("", "foo"))
+def test_str(table_template, design_space_2, name):
+    """Check that a design space is correctly rendered."""
+    if name:
+        design_space_2.name = name
+    table_template = f"Design space: {name}\n" + table_template
+    assert table_template.format(index_0="[0]", index_1="[1]") == str(design_space_2)
 
 
 @pytest.mark.parametrize(
@@ -1141,7 +1169,6 @@ def test_current_x_setter(current_x, current_x_array, dtype, a_type, has_current
 
     design_space._current_value = current_x
     assert design_space._current_value == current_x
-    assert_equal(design_space._DesignSpace__current_value_array, current_x_array)
     assert design_space._DesignSpace__common_dtype == dtype
     assert design_space._DesignSpace__has_current_value is has_current_value
 
@@ -1331,3 +1358,60 @@ def test_get_current_value(fbb_design_space, names, cast, normalize, as_dict):
         expected = fbb_design_space.dict_to_array(expected, variable_names=names)
 
     assert_equal(result, expected)
+
+
+@pytest.mark.parametrize("as_dict", [True, False])
+def test_get_current_value_empty_names(as_dict):
+    design_space = DesignSpace()
+    assert not design_space.get_current_value(variable_names=[], as_dict=as_dict)
+
+
+def test_get_current_value_bad_names():
+    design_space = DesignSpace()
+    match = "There are no such variables named: bar, foo."
+    with pytest.raises(ValueError, match=match):
+        design_space.get_current_value(variable_names=["foo", "bar"])
+
+
+@pytest.mark.parametrize(
+    "l_b,u_b,value",
+    [
+        (None, None, array([0, 0])),
+        (array([1, 2]), None, array([1, 2])),
+        (array([1, 2]), array([2, 4]), array([1, 3])),
+        (None, array([1, 2]), array([1, 2])),
+    ],
+)
+def test_initialize_missing_current_values(l_b, u_b, value):
+    """Check the initialization of the missing current values."""
+    design_space = DesignSpace()
+    design_space.add_variable(
+        "x", size=2, var_type=design_space.INTEGER, l_b=l_b, u_b=u_b
+    )
+    design_space.initialize_missing_current_values()
+    assert_equal(design_space["x"].value, value)
+
+
+def test_get_current_value_order():
+    """Check that the order of variables is correctly handled in get_current_value."""
+    design_space = DesignSpace()
+    design_space.add_variable("x", value=0.0)
+    design_space.add_variable("y", value=1.0)
+    assert_equal(design_space.get_current_value(as_dict=False), array([0.0, 1.0]))
+    assert_equal(
+        design_space.get_current_value(as_dict=False, variable_names=["x", "y"]),
+        array([0.0, 1.0]),
+    )
+    assert_equal(
+        design_space.get_current_value(as_dict=False, variable_names=["y", "x"]),
+        array([1.0, 0.0]),
+    )
+
+
+def test_export_import_with_none_value(tmp_wd):
+    """Check that a design space exported without default value can be imported."""
+    design_space = DesignSpace()
+    design_space.add_variable("x")
+    design_space.export_to_txt("foo.txt")
+    txt_design_space = DesignSpace.read_from_txt("foo.txt")
+    assert txt_design_space == design_space
