@@ -17,12 +17,13 @@
 #                         documentation
 #        :author: Francois Gallard, Matthias De Lozzo
 #    OTHER AUTHORS   - MACROSCOPIC CHANGES
+from __future__ import annotations
+
 import logging
 import re
 import shutil
 from pathlib import Path
 from typing import Iterator
-from typing import Union
 
 import h5py
 import pytest
@@ -238,7 +239,7 @@ def test_hash_discontiguous_array(input_c, input_f):
     assert hash_data_dict({"i": input_c}) == hash_data_dict({"i": input_f})
 
 
-def func(x: Union[int, float]) -> Union[int, float]:
+def func(x: int | float) -> int | float:
     """Dummy function to test the cache."""
     y = x
     return y
@@ -652,3 +653,20 @@ def test_export_to_dataset_and_entries(
     else:
         assert len(entries) == 1
         assert entries[0] == last_entry
+
+
+@pytest.mark.parametrize(
+    "data",
+    (
+        arange(2),
+        [0, 0],
+        {
+            0: None,
+            1: None,
+        },
+    ),
+)
+def test_names_to_sizes(simple_cache, data):
+    """Verify the ``names_to_sizes`` attribute."""
+    simple_cache.cache_outputs({"index": 1}, {"o": data})
+    assert simple_cache.names_to_sizes == {"index": 1, "o": 2}
