@@ -17,6 +17,8 @@
 #                       initial documentation
 #        :author: Francois Gallard
 #    OTHER AUTHORS   - MACROSCOPIC CHANGES
+from __future__ import annotations
+
 import math
 import unittest
 from operator import mul
@@ -25,13 +27,14 @@ from unittest import mock
 
 import numpy as np
 import pytest
+from gemseo.core.mdofunctions.concatenate import Concatenate
 from gemseo.core.mdofunctions.function_generator import MDOFunctionGenerator
 from gemseo.core.mdofunctions.mdo_function import MDOFunction
-from gemseo.core.mdofunctions.mdo_function import MDOLinearFunction
-from gemseo.core.mdofunctions.mdo_function import MDOQuadraticFunction
-from gemseo.core.mdofunctions.mdo_function import SetPtFromDatabase
+from gemseo.core.mdofunctions.mdo_linear_function import MDOLinearFunction
+from gemseo.core.mdofunctions.mdo_quadratic_function import MDOQuadraticFunction
 from gemseo.core.mdofunctions.norm_db_function import NormDBFunction
 from gemseo.core.mdofunctions.norm_function import NormFunction
+from gemseo.core.mdofunctions.set_pt_from_database import SetPtFromDatabase
 from gemseo.problems.analytical.power_2 import Power2
 from gemseo.problems.sobieski.disciplines import SobieskiMission
 from gemseo.utils.data_conversion import concatenate_dict_of_arrays_to_array
@@ -60,11 +63,6 @@ class TestMdofunction(unittest.TestCase):
         for x in range(100):
             assert f(x) == math.sin(x)
 
-        self.assertRaises(TypeError, MDOFunction, math.sin, 1)
-        self.assertRaises(TypeError, MDOFunction, math.sin, "sin", jac="cos")
-        self.assertRaises(TypeError, MDOFunction, math.sin, "sin", expr=math.sin)
-        self.assertRaises(TypeError, MDOFunction, math.sin, "sin", dim=1.3)
-
         self.assertRaises(TypeError, MDOFunction, math.sin, "sin", outvars=1.3)
         f2 = MDOFunction(
             math.sin, "sin", outvars=array(["sin"]), f_type=MDOFunction.TYPE_EQ
@@ -403,7 +401,7 @@ class TestMdofunctiongenerator(unittest.TestCase):
 
     def test_wrong_default_inputs(self):
         sr = SobieskiMission()
-        sr.default_inputs = {"y_34": [1]}
+        sr.default_inputs = {"y_34": array([1])}
         gen = MDOFunctionGenerator(sr)
         range_f_z = gen.get_function(["x_shared"], ["y_4"])
         self.assertRaises(ValueError, range_f_z, array([1.0]))
@@ -787,9 +785,16 @@ def test_multiplication_by_scalar(expr, op, op_name, func, jac):
     f_op_2 = op(f, 2)
     suffix = ""
     if expr:
-        suffix = f" = 2{op_name}{expr}"
+        if op_name == "*":
+            suffix = f" = 2*{expr}"
+        else:
+            suffix = f" = {expr}/2"
+
+    if op_name == "*":
+        assert repr(f_op_2) == "2*f(x)" + suffix
+    else:
+        assert repr(f_op_2) == "f/2(x)" + suffix
 
-    assert repr(f_op_2) == f"2{op_name}f(x)" + suffix
     assert f_op_2(2) == func
     assert f_op_2.jac(2) == jac
 
@@ -864,3 +869,51 @@ def test_serialize_deserialize(activate_counters, mdo_function, kwargs, value, t
         if k not in s_func_u_dict:
             ok = False
     assert ok
+
+
+@pytest.mark.parametrize(
+    "force_real,expected", [(False, array([1j])), (True, array([0.0]))]
+)
+def test_force_real(force_real, expected):
+    """Verify the use of force_real."""
+    f = MDOFunction(lambda x: x, "f", force_real=force_real)
+    assert f.evaluate(array([1j])) == expected
+
+
+@pytest.mark.parametrize(
+    "ft1,ft2,ft", [("", "", ""), ("obj", "", "obj"), ("", "obj", "obj")]
+)
+def test_f_type_sum_two_functions(ft1, ft2, ft):
+    """Verify the f_type of the sum of two functions."""
+    f = MDOFunction(lambda x: x, "f1", f_type=ft1) + MDOFunction(
+        lambda x: x, "f2", f_type=ft2
+    )
+    assert f.f_type == ft
+
+
+@pytest.mark.parametrize("f_type", ["", "obj"])
+def test_f_type_sum_function_and_number(f_type):
+    """Verify the f_type of the sum of a function and a number."""
+    f = MDOFunction(lambda x: x, "f", f_type=f_type) + 1.0
+    assert f.f_type == f_type
+
+
+@pytest.mark.parametrize(
+    "f_out,g_out,h_out",
+    [
+        (None, None, []),
+        (["a"], None, []),
+        (None, ["b"], []),
+        (["a"], ["b"], ["a", "b"]),
+    ],
+)
+def test_concatenate(f_out, g_out, h_out):
+    """Check ``Concatenate.outvars``."""
+    f = Concatenate(
+        [
+            MDOFunction(lambda x: x, "f", outvars=f_out),
+            MDOFunction(lambda x: x, "g", outvars=g_out),
+        ],
+        "h",
+    )
+    assert f.outvars == h_out
