@@ -17,6 +17,8 @@
 #                         documentation
 #        :author: Francois Gallard
 #    OTHER AUTHORS   - MACROSCOPIC CHANGES
+from __future__ import annotations
+
 import os
 
 import numpy as np
@@ -38,6 +40,8 @@ def test_compare_mda_jacobi_gs():
     out2 = mda2.execute()
 
     for key, value1 in out1.items():
+        if key == mda.RESIDUALS_NORM:
+            continue
         assert (
             np.linalg.norm(np.array(out2[key] - value1)) / np.linalg.norm(value1) < 1e-2
         )
@@ -56,6 +60,8 @@ def test_mda_jacobi_newton_hybrid(sellar_disciplines):
     out3 = mda_hybrid.execute()
 
     for key, value1 in out1.items():
+        if key == mda_j.RESIDUALS_NORM:
+            continue
         nv1 = np.linalg.norm(value1)
         if nv1 > 1e-14:
             assert (
