@@ -17,6 +17,9 @@
 #        :author: Damien Guenot
 #        :author: Francois Gallard
 #    OTHER AUTHORS   - MACROSCOPIC CHANGES
+from __future__ import annotations
+
+import sys
 from pathlib import Path
 
 import pytest
@@ -43,6 +46,7 @@ def test_get_constraints():
     assert len(cstr) == 1
 
 
+@pytest.mark.skipif(sys.version_info < (3, 8), reason="requires Python 3.8 or greater")
 @image_comparison(
     [
         "power2_2_variables",
@@ -74,6 +78,7 @@ def test_opt_hist_const(pyplot_close_all):
     post.figures
 
 
+@pytest.mark.skipif(sys.version_info < (3, 8), reason="requires Python 3.8 or greater")
 @pytest.mark.parametrize(
     "problem_path,baseline_images",
     [
@@ -100,7 +105,7 @@ def test_opt_hist_const(pyplot_close_all):
         ),
     ],
 )
-@image_comparison(None, extensions=["png"])
+@image_comparison(None)
 def test_opt_hist_from_database(baseline_images, problem_path, pyplot_close_all):
     """Test the generation of the plots from databases.
 
