@@ -16,6 +16,8 @@
 #    INITIAL AUTHORS - API and implementation and/or documentation
 #        :author: Francois Gallard
 #    OTHER AUTHORS   - MACROSCOPIC CHANGES
+from __future__ import annotations
+
 import unittest
 
 from gemseo.algos.opt.opt_factory import OptimizersFactory
@@ -41,8 +43,6 @@ class TestOptPostProcessor(unittest.TestCase):
         class PostNoGram(OptPostProcessor):
             """"""
 
-            pass
-
         self.assertRaises(Exception, PostNoGram, self.problem)
 
     def test_execute(self):
