@@ -16,6 +16,10 @@
 #    INITIAL AUTHORS - API and implementation and/or documentation
 #       :author: Francois Gallard
 #    OTHER AUTHORS   - MACROSCOPIC CHANGES
+from __future__ import annotations
+
+import sys
+
 import pytest
 from gemseo.post.quad_approx import QuadApprox
 from gemseo.utils.testing import image_comparison
@@ -35,6 +39,7 @@ TEST_PARAMETERS = {
 }
 
 
+@pytest.mark.skipif(sys.version_info < (3, 8), reason="requires Python 3.8 or greater")
 @pytest.mark.parametrize(
     "use_standardized_objective, function, baseline_images",
     TEST_PARAMETERS.values(),
