@@ -12,6 +12,8 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with this program; if not, write to the Free Software Foundation,
 # Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+from __future__ import annotations
+
 import runpy
 from pathlib import Path
 from shutil import copytree
@@ -32,6 +34,7 @@ EXAMPLE_PATHS = [
     "example_path", EXAMPLE_PATHS, ids=(path.name for path in EXAMPLE_PATHS)
 )
 def test_script_execution(example_path, tmp_wd, monkeypatch):
-    Path(copytree(example_path.parent, tmp_wd, dirs_exist_ok=True))
-    monkeypatch.chdir(tmp_wd)
+    dir_path = tmp_wd / example_path.parent.name
+    Path(copytree(example_path.parent, dir_path))
+    monkeypatch.chdir(dir_path)
     runpy.run_path(example_path.name)
