@@ -17,6 +17,8 @@
 #                      initial documentation
 #        :author:  Matthias De Lozzo
 #    OTHER AUTHORS   - MACROSCOPIC CHANGES
+from __future__ import annotations
+
 from os import remove
 
 import pytest
@@ -24,6 +26,23 @@ from gemseo.algos.parameter_space import ParameterSpace
 from gemseo.api import create_discipline
 from gemseo.uncertainty.sensitivity.sobol.analysis import SobolAnalysis
 from numpy import pi
+from numpy.testing import assert_equal
+
+
+@pytest.fixture
+def sobol() -> SobolAnalysis:
+    """A Sobol' analysis."""
+    discipline = create_discipline(
+        "AnalyticDiscipline",
+        expressions={"y": "sin(x1)+7*sin(x2)**2+0.1*x3**4*sin(x1)"},
+        name="Ishigami",
+    )
+    space = ParameterSpace()
+    for name in ["x1", "x2", "x3"]:
+        space.add_random_variable(
+            name, "OTUniformDistribution", minimum=-pi, maximum=pi
+        )
+    return SobolAnalysis([discipline], space, 100)
 
 
 def test_sobol_algos():
@@ -31,19 +50,8 @@ def test_sobol_algos():
     assert SobolAnalysis.AVAILABLE_ALGOS == expected
 
 
-def test_sobol(tmp_path):
-    expressions = {"y": "sin(x1)+7*sin(x2)**2+0.1*x3**4*sin(x1)"}
+def test_sobol(sobol, tmp_path):
     varnames = ["x1", "x2", "x3"]
-    discipline = create_discipline(
-        "AnalyticDiscipline", expressions=expressions, name="Ishigami"
-    )
-    space = ParameterSpace()
-    for name in varnames:
-        space.add_random_variable(
-            name, "OTUniformDistribution", minimum=-pi, maximum=pi
-        )
-
-    sobol = SobolAnalysis([discipline], space, 100)
     assert sobol.main_method == sobol._FIRST_METHOD
     sobol.compute_indices()
     indices = sobol.indices
@@ -118,3 +126,11 @@ def test_sobol_outputs(tmp_path):
     sobol = SobolAnalysis([discipline], space, 100)
     sobol.compute_indices("y1")
     assert {"y1"} == set(sobol.main_indices.keys())
+
+
+def test_save_load(sobol, tmp_wd):
+    """Check saving and loading a SobolAnalysis."""
+    sobol.save("foo.pkl")
+    new_sobol = SobolAnalysis.load("foo.pkl")
+    assert_equal(new_sobol.dataset.data, sobol.dataset.data)
+    assert new_sobol.default_output == sobol.default_output
