@@ -16,10 +16,9 @@
 #    INITIAL AUTHORS - API and implementation and/or documentation
 #        :author: Charlie Vanaret
 #    OTHER AUTHORS   - MACROSCOPIC CHANGES
+from __future__ import annotations
+
 import re
-from typing import Dict
-from typing import List
-from typing import Union
 
 import pytest
 from gemseo.utils.data_conversion import array_to_dict
@@ -39,7 +38,7 @@ from numpy import ndarray
 
 
 @pytest.fixture
-def dict_to_be_updated() -> Dict[str, ndarray]:
+def dict_to_be_updated() -> dict[str, ndarray]:
     """A dictionary to be updated."""
     return {"x": array([0.0, 1.0]), "y": array([2.0]), "z": array([3, 4])}
 
@@ -156,7 +155,7 @@ def xy_sizes():
 
 
 @pytest.fixture(scope="module")
-def xy_dict() -> Dict[str, ndarray]:
+def xy_dict() -> dict[str, ndarray]:
     """The values of x and y."""
     return {"x": array([1.0]), "y": array([2.0, 3.0])}
 
@@ -164,7 +163,7 @@ def xy_dict() -> Dict[str, ndarray]:
 @pytest.fixture(params=[False, True])
 def possibly_nested_xy_dict(
     request,
-) -> Dict[str, Union[ndarray, Dict[str, ndarray]]]:
+) -> dict[str, ndarray | dict[str, ndarray]]:
     """A NumPy array with values for x and y."""
     if request.param:
         return {"x": {"x_1": array([1.0])}, "y": array([2.0, 3.0])}
@@ -230,7 +229,7 @@ def test_split_array_to_dict_of_arrays_without_inconsistency_check(xy_array, y_s
 
 
 @pytest.fixture(scope="module")
-def list_grouped_xy_dict(xy_dict) -> List[Dict[str, Dict[str, ndarray]]]:
+def list_grouped_xy_dict(xy_dict) -> list[dict[str, dict[str, ndarray]]]:
     """A list of grouped data dictionaries."""
     return [
         {"g1": {"x": xy_dict["x"]}, "g2": {"y": xy_dict["y"]}},
@@ -239,7 +238,7 @@ def list_grouped_xy_dict(xy_dict) -> List[Dict[str, Dict[str, ndarray]]]:
 
 
 @pytest.fixture(scope="module")
-def list_xy_dict(xy_dict) -> List[Dict[str, ndarray]]:
+def list_xy_dict(xy_dict) -> list[dict[str, ndarray]]:
     """A list of data dictionaries."""
     return [
         {"x": xy_dict["x"], "y": xy_dict["y"]},
