@@ -13,6 +13,9 @@
 # along with this program; if not, write to the Free Software Foundation,
 # Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 """Test the function that save and/or show a Matplotlib figure."""
+from __future__ import annotations
+
+from pathlib import Path
 from unittest.mock import patch
 
 import pytest
@@ -23,17 +26,14 @@ from matplotlib import pyplot as plt
 @pytest.mark.parametrize("file_path", [None, "file_name.pdf"])
 @pytest.mark.parametrize("show", [True, False])
 @pytest.mark.parametrize("fig_size", [[10, 10], None])
-def test_process(tmp_path, pyplot_close_all, file_path, show, fig_size):
+def test_process(tmp_wd, pyplot_close_all, file_path, show, fig_size):
     """Verify that a Matplotlib figure is correctly saved."""
     fig, axes = plt.subplots()
 
-    if file_path is not None:
-        file_path = tmp_path / file_path
-
     with patch("matplotlib.pyplot.savefig"), patch("matplotlib.pyplot.show"):
         save_show_figure(fig, show, file_path, fig_size)
 
     if file_path is not None:
-        assert file_path.exists()
+        assert Path(file_path).exists()
 
     plt.fignum_exists(fig.number)
